--
-- Mod: FS22_RealLifeNumbers by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- Script: RealNumbersSprayTypes by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- e-mail: kaj-aage.henneberg@outlook.dk
-- Download: www.modhoster.com
-- All rights reserved.
-- Version 1.0.0.6 
-- 26-11-2021

--
-- Objective
--
-- This script reads the data in the xml file my_sprayTypes.xml located in the folder
-- modSettings/RealLifeNumbers/savegame(n) and save the numbers into the game.
-- 
-- This way you can use different parameter values for different maps and adjust the 
-- values to fit values more suitable to a specific region/state/country.

RealNumbersSprayTypes = {};

local function myPrintScaledValue(text, number1, number2,textWidth, unit)
	print(string.format("%s : default value =  %12.5f : my value = %12.5f %s", text..string.rep(" ",textWidth-string.len(text)),number1, number2,"    "..unit));
end;

function RealNumbersSprayTypes:loadMap(name)
	local useMyXMLfile = true;
	local textWidth = 40;
	print("\n --- RealNumbersSprayTypes.lua started --- \n");

	RN.sprayTypes = {};

	local modSettingsDir = getUserProfileAppPath() .. "modSettings";	
	if modSettingsDir == nil then
		print(" ");
		print("modSettingsDir undefined");
		print(" ");
	end;
	local savegameIndex = g_currentMission.missionInfo.savegameIndex;
	local RNmodSettingsDir = modSettingsDir .. "/RealLifeNumbers/savegame" .. savegameIndex;
	
	local mySprayTypeXML = RNmodSettingsDir.."/my_sprayTypes.xml";


	if fileExists(mySprayTypeXML) then
		print("\n --- my XML file is used --- \n")
		local xmlFile = loadXMLFile("sprayTypes", mySprayTypeXML);
		print("Loading file:");
		print(mySprayTypeXML);
		print(" ");

		local i = 0;
		while true do
			local xmlKey = string.format("map.sprayTypes.sprayType(%d)", i);
			if not hasXMLProperty(xmlFile, xmlKey) then
--			print(" does not have xml property");
				break;
			end;
				local sprayName = getXMLString(xmlFile, xmlKey .. "#name");	
				local oldValue = g_sprayTypeManager.nameToSprayType[sprayName].litersPerSecond;
				local myValue = getXMLFloat(xmlFile, xmlKey.. "#litersPerSecond");
				g_sprayTypeManager.nameToSprayType[sprayName].litersPerSecond = myValue
				myPrintScaledValue(sprayName.." litersPerSecond",oldValue,myValue,textWidth," ");
			i = i + 1;
		end;	
	else
		print("xml file does not exist for this savegame. Default parameters are used.");
		useMyXMLfile = false;
--		createFolder(RNmodSettingsDir);
	end;
	print("\n --- RealNumbersSprayTypes.lua finished --- \n");

end;


function RealNumbersSprayTypes:keyEvent(unicode, sym, modifier, isDown)
end;
function RealNumbersSprayTypes:update(dt)
end;
function RealNumbersSprayTypes:draw()
end;
function RealNumbersSprayTypes:deleteMap()
end;
function RealNumbersSprayTypes:mouseEvent(posX, posY, isDown, isUp, button)
end;

addModEventListener(RealNumbersSprayTypes);






