--
-- Mod: FS22_RealLifeNumbers by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- Script: RealNumbersStorePrices by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- e-mail: kaj-aage.henneberg@outlook.dk
-- Download: www.modhoster.com
-- All rights reserved.
-- Version 1.0.0.6
-- 26-11-2021

RealNumbersStorePrices = {};

function myPrintStorePrices(text1, text2, number1, number2,textWidth1, textWidth2, unit)
	print(string.format("%s : %s  Volume %6.0f : Price = %8.0f %s", 
			text1..string.rep(" ",textWidth1-string.len(text1)),
			text2..string.rep(" ",textWidth2-string.len(text2)),
			number1, number2,"    "..unit));
end;

local function print_r (t, indent, done)
  done = done or {}
  indent = indent or ''
  local nextIndent -- Storage for next indentation value
  for key, value in pairs (t) do
    if type (value) == "table" and not done [value] then
      nextIndent = nextIndent or
          (indent .. string.rep(' ',string.len(tostring (key))+2))
          -- Shortcut conditional allocation
      done [value] = true
      print (indent .. "[" .. tostring (key) .. "] => Table {");
      print  (nextIndent .. "{");
      print_r (value, nextIndent .. string.rep(' ',2), done)
      print  (nextIndent .. "}");
    else
      print  (indent .. "[" .. tostring (key) .. "] => " .. tostring (value).."")
    end
  end
end

--[[ not used. Global functions used instaed

function RealNumbersStorePrices.loadSpecsFromXML(item)
    if item.specs == nil then
        local storeItemXmlFile = XMLFile.load("storeItemXML", item.xmlFilename, item.xmlSchema)
        item.specs = RealNumbersStorePrices.getSpecsFromXML(g_storeManager:getSpecTypes(), item.species, storeItemXmlFile, item.customEnvironment, item.baseDir)
        storeItemXmlFile:delete()
    end

    if item.bundleInfo ~= nil then
        local bundleItems = item.bundleInfo.bundleItems
        for i=1, #bundleItems do
            RealNumbersStorePrices.loadSpecsFromXML(bundleItems[i].item)
        end
    end
end
function RealNumbersStorePrices.getSpecsFromXML(specTypes, species, xmlFile, customEnvironment, baseDirectory)
    local specs = {}
    for _, specType in pairs(specTypes) do
        if specType.species == species then
            if specType.loadFunc ~= nil then
                specs[specType.name] = specType.loadFunc(xmlFile, customEnvironment, baseDirectory)
            end
        end
    end
    return specs
end
--]]


function RealNumbersStorePrices:loadMap(name)
	local currency = "€";	-- or  "$" or "£"
	local gameMoneyUnit = g_i18n.moneyUnit;
	if gameMoneyUnit == 1 then
        currency = "€";
	elseif gameMoneyUnit == 2 then
        currency = "$";
	elseif gameMoneyUnit == 3 then
        currency = "£";
	end;
	RN.storePriceScaling = {};
	RN.storePriceScaling.bales 			= 0.1;			-- default RLN value = 0.1; vanilla game = 1
	RN.storePriceScaling.bigbags 		= 0.1;			-- default RLN value = 0.1; vanilla game = 1
	RN.storePriceScaling.bigbagpallets 	= 0.1;			-- default RLN value = 0.1; vanilla game = 1
	RN.storePriceScaling.pallets 		= 0.1;			-- default RLN value = 0.1; vanilla game = 1
	RN.notRunYetRealNumbersStorePrices 	= true;
	RN.upStartRealNumbersStorePrices 	= true;

	RN.dailyUpKeepScalingIsActive		= true;			-- set to false dailyUpKeep should not be scaled
	local textWidth1 = 35;
	local textWidth2 = 25;
	local fillName = " ";
	local fillTypeName = " ";
	local baleFillTypeName = " ";
	local baleVolume = 0;
	local xmlFileName2 = " ";
	local itemName = " ";
	local storePrice = 0;
	
	if g_currentMission.environment.daysPerPeriod ~= nil then
		RN.gameDaysPerYear = g_currentMission.environment.daysPerPeriod * 12;
	else
		RN.gameDaysPerYear = 36;
	end;
	
	RN.placeableCategories = {"ANIMALPENS","BALES","BEEHIVES","BIGBAGPALLETS","BIGBAGS","DIESELTANKS",
								"FARMHOUSES","FENCES","FILLABLETANKS","FLOODLIGHTING","GARDENSHEDS",
								"GENERATORS","PALLETS","PLACEABLEMISC","PRODUCTIONPOINTS","SELLINGPOINTS",
								"SHEDS","SILOS","SILOEXTENSIONS","STORAGES","TREES","WATERTANKS"};

	RN.dailyUpkeep = {}; -- scaling factors for different categories of items.
	
	-- Daily upkeep covers daily maintenance (e.g. greasing, not repair), tax and insurance
	-- Fuel and vehicle repair is not included in daily upkeep
	-- Scaling factor is multipled by retail price to obtain actual dailyUpkeep
	-- Scaling factor is = 0.01 * percentage of retail price / gamedays per year
	-- Example: item price = 100,000 eu
	-- Maintenance cost per year: 0.5% = 500 eu
	-- Tax cost per year		: 0.1% = 100 eu
	-- Insurance cost per year  : 0.1% = 100 eu
	-- Total MTI cost per year  : 0.7% = 700 eu 
	-- 
	-- Change as you see fit. The values defined here are guesses.
	
	RN.dailyUpkeep["motorizedVehicle"] 	= 0.7	/(100*RN.gameDaysPerYear);		-- Maintenance, tax and insurance
	RN.dailyUpkeep["implement"]			= 0.2	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["handTool"] 			= 0.2	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["ANIMALPENS"] 		= 0.5	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["BALES"] 			= 0.01	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["BEEHIVES"] 			= 0.2	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["BIGBAGPALLETS"] 	= 0.01	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["BIGBAGS"] 			= 0.01	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["DIESELTANKS"] 		= 0.05	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["FARMHOUSES"] 		= 0.5	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["FENCES"] 			= 0.05	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["FILLABLETANKS"] 	= 0.05	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["FLOODLIGHTING"] 	= 0.2	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["GARDENSHEDS"] 		= 0.1	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["GENERATORS"] 		= 0.2	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["PALLETS"] 			= 0.01	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["PLACEABLEMISC"] 	= 0.1	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["PRODUCTIONPOINTS"] 	= 0.5	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["SELLINGPOINTS"] 	= 0.2	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["SHEDS"] 			= 0.2	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["SILOS"] 			= 0.2	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["SILOEXTENSIONS"] 	= 0.2	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["STORAGES"] 			= 0.2	/(100*RN.gameDaysPerYear);		-- Maintenance
	RN.dailyUpkeep["TREES"] 			= 0.01	/(100*RN.gameDaysPerYear);		-- Maintenance	
	RN.dailyUpkeep["WATERTANKS"] 		= 0.01	/(100*RN.gameDaysPerYear);		-- Maintenance		

	print("\n --- RealNumbersStorePrices.lua started --- \n");

	for i, item in pairs(g_storeManager.items) do

-- BALES

		if g_storeManager.items[i].price   ~= nil then
			if g_storeManager.items[i].categoryName == "BALES" then
				storePrice = 0;
				baleVolume = 0;
				itemName = tostring(item.name);
--				print("Bale : "..itemName);
				StoreItemUtil.loadSpecsFromXML(item);
--				if item.specs ~= nil then DebugUtil.printTableRecursively(item,"_",0,1);end;
				local itemId = item.id;
--				print("itemId : "..itemId);
				local specs = item.specs;
				local capacity = specs.capacity;
				local fillType = specs.fillTypes;
				if fillType ~= nil then						
--					print(type(fillType.fillTypeNames));
--					print(fillType.fillTypeNames);
					local whiteSpaceInString = string.find(fillType.fillTypeNames, " ");	-- Some items can carry several fillTypes, take the first in the list
					if whiteSpaceInString ~= nil then				
--						print(whiteSpaceInString);
						fillName = string.upper(string.sub(fillType.fillTypeNames, 1,whiteSpaceInString-1)); -- take out the first in the list
					else
						fillName = string.upper(fillType.fillTypeNames);
					end;
--					print(fillName);
					local itemFillTypes = g_fillTypeManager.nameToFillType[fillName];
					local fillTypeIndex = g_fillTypeManager.nameToIndex[fillName];
--					print("fillTypeIndex : "..fillTypeIndex);
--					print("Loading file : "..item.xmlFilename);
					local xmlFile = loadXMLFile("fillTypes", item.xmlFilename ); 
					local xmlKey1 = string.format("vehicle.fillUnit.fillUnitConfigurations.fillUnitConfiguration.fillUnits.fillUnit");
					if not hasXMLProperty(xmlFile, xmlKey1) then
						print(" xmlKey1 does not have xml property ");
					else
						fillTypeName = string.upper(getXMLString(xmlFile, xmlKey1 .. "#fillTypes"));
					end;
--					print("fillTypeName : "..fillTypeName);

					local xmlKey2 = string.format("vehicle.multipleItemPurchase");
					if not hasXMLProperty(xmlFile, xmlKey2) then
						print(" does not have xml property");
					else
						xmlFileName2 = getXMLString(xmlFile, xmlKey2 .. "#filename")
					end;
					xmlFileName2 = string.sub(xmlFileName2, 2,-1);		-- remove $ sign
--					print("loading : "..xmlFileName2);
					local xmlFile2 = loadXMLFile("filename", xmlFileName2);

					local i = 0;
					while true do
						local xmlKey3 = string.format("bale.fillTypes.fillType(%d)", i);
						if not hasXMLProperty(xmlFile2, xmlKey3) then
							print(" does not have xml property");
						else
							baleFillTypeName = string.upper(getXMLString(xmlFile2, xmlKey3 .. "#name"));
							baleVolume = getXMLString(xmlFile2, xmlKey3 .. "#capacity");
							if baleFillTypeName == fillTypeName then break;end;							
						end;
						i = i + 1;
					end; --while loop

					item.price = baleVolume * itemFillTypes.pricePerLiter;
					storePrice = math.floor(item.price);
					myPrintStorePrices(itemName, fillTypeName, baleVolume, storePrice, textWidth1, textWidth2, currency);					

--					print("Item volume (L) : "..baleVolume);
--					print("Item pricePerLiter :"..itemFillTypes.pricePerLiter);
--					print("Item price :"..item.price);
				end;

				for n = 1,8 do
					g_storeManager.items[i].configurations.multipleItemPurchaseAmount[n].price = (n-1) * item.price;
				end;
			end;

-- BIGBAGS

			if g_storeManager.items[i].categoryName == "BIGBAGS" then
				itemName = item.name; 
				storePrice = 0;
				itemVolume = 0;
--				print("Bigbag : "..item.name);
				StoreItemUtil.loadSpecsFromXML(item)
--				if item.specs ~= nil then print_r(item.specs);end;
--				if item.specs ~= nil then DebugUtil.printTableRecursively(item.specs,"_",0,3);end;
				local specs = item.specs;
				local capacity = specs.capacity;
				local fillType = specs.fillTypes;
				if fillType ~= nil then						
--					print(type(fillType.fillTypeNames));
--					print(fillType.fillTypeNames);
					local whiteSpaceInString = string.find(fillType.fillTypeNames, " ");
					if whiteSpaceInString ~= nil then				
--						print(whiteSpaceInString);
						fillName = string.upper(string.sub(fillType.fillTypeNames, 1,whiteSpaceInString-1));
					else
						fillName = string.upper(fillType.fillTypeNames);
					end;
--					print(fillName);
					local itemFillTypes = g_fillTypeManager.nameToFillType[fillName];
					if itemFillTypes ~= nil then 
						
						if itemFillTypes.name ~= nil then
							fillName = string.upper(itemFillTypes.name); -- may be a list of fill types <<<<<<
--							print(fillName);
							local cap1 = capacity[1];
							local cap11 = cap1[1];
							itemVolume = cap11.capacity;
--							print("Item volume (L) : "..itemVolume);
--							print("Item pricePerLiter :"..itemFillTypes.pricePerLiter);
							item.price = itemVolume * itemFillTypes.pricePerLiter;	
							storePrice = math.floor(item.price);
						end;
					end;
					myPrintStorePrices(itemName, fillName, itemVolume, storePrice, textWidth1, textWidth2, currency);
				end;
--				g_storeManager.items[i].price   = g_storeManager.items[i].price * RN.storePriceScaling.bigbags;
			end;

-- BIGBAGPALLETS

			if g_storeManager.items[i].categoryName == "BIGBAGPALLETS" then
				itemName = item.name; 
				storePrice = 0;
				itemVolume = 0;
--				print("Bigbagpallet : "..item.name);
				StoreItemUtil.loadSpecsFromXML(item)
--				if item.specs ~= nil then print_r(item.specs);end;
				local specs = item.specs;
				local capacity = specs.capacity;
				local fillType = specs.fillTypes;
				if fillType ~= nil then				
--					print(type(fillType.fillTypeNames));
--					print(fillType.fillTypeNames);
					local whiteSpaceInString = string.find(fillType.fillTypeNames, " ");
					if whiteSpaceInString ~= nil then				
--						print(whiteSpaceInString);
						fillName = string.upper(string.sub(fillType.fillTypeNames, 1,whiteSpaceInString-1));
					else
						fillName = string.upper(fillType.fillTypeNames);
					end;
--					print(fillName);
					local itemFillTypes = g_fillTypeManager.nameToFillType[fillName];
					if itemFillTypes ~= nil then 
						
						if itemFillTypes.name ~= nil then
							fillName = string.upper(itemFillTypes.name); -- may be a list of fill types <<<<<<
--							print(fillName);
							local cap1 = capacity[1];
							local cap11 = cap1[1];
							itemVolume = cap11.capacity;
--							print("Item volume (L) : "..itemVolume);
--							print("Item pricePerLiter :"..itemFillTypes.pricePerLiter);
							item.price = itemVolume * itemFillTypes.pricePerLiter;
							storePrice = math.floor(item.price);
						end;
					end;
				end;
				myPrintStorePrices(itemName, fillName, itemVolume, storePrice, textWidth1, textWidth2, currency);				
--				g_storeManager.items[i].price   = g_storeManager.items[i].price * RN.storePriceScaling.bigbagpallets;
			end;

-- PALLETS
			if g_storeManager.items[i].categoryName == "PALLETS" then
				itemName = item.name;
				storePrice = 0;
				itemVolume = 0;
--				print("Pallet : "..item.name);
				StoreItemUtil.loadSpecsFromXML(item)
--				if item.specs ~= nil then print_r(item.specs);end;
				local specs = item.specs;
				local capacity = specs.capacity;
				local fillType = specs.fillTypes;
				if fillType.fillTypeNames ~= nil then
--					print(type(fillType.fillTypeNames));
--					print(fillType.fillTypeNames);
					local whiteSpaceInString = string.find(fillType.fillTypeNames, " ");
					if whiteSpaceInString ~= nil then				
--						print(whiteSpaceInString);
						fillName = string.upper(string.sub(fillType.fillTypeNames, 1,whiteSpaceInString-1));
					else
						fillName = string.upper(fillType.fillTypeNames);
					end;
--					print(fillName);
					local itemFillTypes = g_fillTypeManager.nameToFillType[fillName];
					if itemFillTypes ~= nil then 
						
						if itemFillTypes.name ~= nil then
							fillName = string.upper(itemFillTypes.name); -- may be a list of fill types <<<<<<
--							print(fillName);
							local cap1 = capacity[1];
							local cap11 = cap1[1];
							itemVolume = cap11.capacity;
--							print("Item volume (L) : "..itemVolume);
--							print("Item pricePerLiter :"..itemFillTypes.pricePerLiter);
							item.price = itemVolume * itemFillTypes.pricePerLiter;
							storePrice = math.floor(item.price);
						end;
					end;
					myPrintStorePrices(itemName, fillName, itemVolume, storePrice, textWidth1, textWidth2, currency);
				end;
--				g_storeManager.items[i].price   = g_storeManager.items[i].price * RN.storePriceScaling.pallets;
			end;
		end;		
	end;
	
	print("\n --- RealNumbersStorePrices.lua finished --- \n");
end;


function RealNumbersStorePrices:keyEvent(unicode, sym, modifier, isDown)
end;

function RealNumbersStorePrices:update(dt)
	if runMinute ~= 8 then RN.notRunYetRealNumbersStorePrices = true; end;
	if runMinute == 8 or RN.upStartRealNumbersStorePrices then
		if RN.notRunYetRealNumbersStorePrices then
			for i, v in pairs(g_storeManager.items) do
				if g_storeManager.items[i].categoryName == "BIGBAGS" then
				
					if g_storeManager.items[i].configurations.multipleItemPurchaseAmount ~= nil then
						for n = 1,8 do
							g_storeManager.items[i].configurations.multipleItemPurchaseAmount[n].price = (n-1) * g_storeManager.items[i].price;
						end;
					end;
				end;
				if g_storeManager.items[i].categoryName == "BIGBAGPALLETS" then
					if g_storeManager.items[i].configurations.multipleItemPurchaseAmount ~= nil then
						for n = 1,8 do
							g_storeManager.items[i].configurations.multipleItemPurchaseAmount[n].price = (n-1) * g_storeManager.items[i].price;
						end;
					end;
				end;	

	-- Define dailyUpkeep
				
				if RN.dailyUpKeepScalingIsActive then
					if g_storeManager.items[i].dailyUpkeep    ~= nil then
						if g_storeManager.items[i].species == "vehicle" then
							g_storeManager.items[i].dailyUpkeep = RN.dailyUpkeep["implement"] * g_storeManager.items[i].price;
							if g_storeManager.items[i].hasLicensePlates then
								g_storeManager.items[i].dailyUpkeep = RN.dailyUpkeep["motorizedVehicle"] * g_storeManager.items[i].price;				
							end;					
						elseif g_storeManager.items[i].species == "handTool" then
							g_storeManager.items[i].dailyUpkeep = RN.dailyUpkeep["handTool"] * g_storeManager.items[i].price;					
						elseif g_storeManager.items[i].species == "placeable" then
							for k = 1,#RN.placeableCategories do
								local category = RN.placeableCategories[k];
								if g_storeManager.items[i].categoryName == category then
	--								print(category);	-- debug
									g_storeManager.items[i].dailyUpkeep = RN.dailyUpkeep[category] * g_storeManager.items[i].price;								
								end;
							end;					
						end;				
					end;
				end;
			end;
			RN.notRunYetRealNumbersStorePrices = false;
			RN.upStartRealNumbersStorePrices = false;
		end;
	end;
end;
function RealNumbersStorePrices:draw()
end;
function RealNumbersStorePrices:deleteMap()
end;
function RealNumbersStorePrices:mouseEvent(posX, posY, isDown, isUp, button)
end;

addModEventListener(RealNumbersStorePrices);







